@@ -1,6 +1,6 @@
 package Proc::Background::Unix;
-$Proc::Background::Unix::VERSION = '1.29_01'; # TRIAL
-$Proc::Background::Unix::VERSION = '1.2901';
+$Proc::Background::Unix::VERSION = '1.29_02'; # TRIAL
+$Proc::Background::Unix::VERSION = '1.2902';
 # ABSTRACT: Unix-specific implementation of process create/wait/kill
 require 5.004_04;
 
@@ -68,16 +68,16 @@ sub _start {
 
   # Fork a child process.
   my ($pipe_r, $pipe_w);
-  if ($self->{_autodie} && defined $FD_CLOEXEC) {
+  if (defined $FD_CLOEXEC) {
     # use a pipe for the child to report exec() errors
-    pipe $pipe_r, $pipe_w or croak "pipe: $!";
+    pipe $pipe_r, $pipe_w or return $self->_fatal("pipe: $!");
     # This pipe needs to be in the non-preserved range that doesn't exist after exec().
     # In the edge case where a pipe received a FD less than $^F, the CLOEXEC flag isn't set.
     # Try again on higher descriptors, then close the lower ones.
     my @rejects;
     while (fileno $pipe_r <= $^F or fileno $pipe_w <= $^F) {
       push @rejects, $pipe_r, $pipe_w;
-      pipe $pipe_r, $pipe_w or croak "pipe: $!";
+      pipe $pipe_r, $pipe_w or return $self->_fatal("pipe: $!");
     }
   }
   my $pid;
@@ -86,18 +86,18 @@ sub _start {
       # parent
       $self->{_os_obj} = $pid;
       $self->{_pid}    = $pid;
-      if (defined $pipe_r) { # implies autodie enabled
+      if (defined $pipe_r) {
         close $pipe_w;
         # wait for child to reply or close the pipe
         local $SIG{PIPE}= sub {};
-        my $msg;
+        my $msg= '';
         while (0 < read $pipe_r, $msg, 1024, length $msg) {}
         close $pipe_r;
         # If child wrote anything to the pipe, it failed to exec.
         # Reap it before dying.
         if (length $msg) {
           waitpid $pid, 0;
-          croak $msg;
+          return $self->_fatal($msg);
         }
       }
       last;
@@ -148,7 +148,7 @@ sub _resolve_file_handle {
   if (!defined $thing) {
     open my $fh, $mode, '/dev/null' or croak "open(/dev/null): $!";
     return $fh;
-  } elsif (ref $thing && (ref $thing eq 'GLOB' or ref($thing)->can('close'))) {
+  } elsif (ref $thing) {
     # use 'undef' to mean no-change
     return (fileno($thing) == fileno($default))? undef : $thing;
   } else {
@@ -180,6 +180,7 @@ sub _waitpid {
 
     # Process finished.  Grab the exit value.
     if ($result == $self->{_os_obj}) {
+      delete $self->{_suspended};
       return (0, $?);
     }
     # Process already reaped.  We don't know the exist status.
@@ -288,7 +289,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 VERSION
 
-version 1.29_01
+version 1.29_02
 
 =head1 COPYRIGHT AND LICENSE
 
