@@ -1,6 +1,6 @@
 package Proc::Background::Win32;
-$Proc::Background::Win32::VERSION = '1.29_01'; # TRIAL
-$Proc::Background::Win32::VERSION = '1.2901';
+$Proc::Background::Win32::VERSION = '1.29_02'; # TRIAL
+$Proc::Background::Win32::VERSION = '1.2902';
 # ABSTRACT: Windows-specific implementation of process create/wait/kill
 require 5.004_04;
 
@@ -114,7 +114,7 @@ sub _resolve_file_handle {
   if (!defined $thing) {
     open my $fh, $mode, 'NUL' or croak "open(NUL): $!";
     return $fh;
-  } elsif (ref $thing && (ref $thing eq 'GLOB' or ref($thing)->can('close'))) {
+  } elsif (ref $thing) {
     return fileno($thing) == fileno($default)? undef : $thing;
   } else {
     open my $fh, $mode, $thing or croak "open($thing): $!";
@@ -133,6 +133,7 @@ sub _waitpid {
   my $result = $self->{_os_obj}->Wait($wait_seconds? int($wait_seconds * 1000) : $blocking ? INFINITE : 0);
   # Process finished.  Grab the exit value.
   if ($result == 1) {
+    delete $self->{_suspended};
     my $exit_code;
     $self->{_os_obj}->GetExitCode($exit_code);
     if ($exit_code == 256 && $self->{_called_terminateprocess}) {
@@ -280,7 +281,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 VERSION
 
-version 1.29_01
+version 1.29_02
 
 =head1 COPYRIGHT AND LICENSE
 
